@@ -1,6 +1,5 @@
 from asyncio import gather
 from dataclasses import dataclass
-from datetime import datetime
 from typing import AsyncIterator, Awaitable, Callable
 from weakref import WeakSet
 
@@ -88,9 +87,7 @@ def build(
     async def broadcast() -> None:
         async for _ in updates:
             tasks = (ws.send_str("NEW -- from server") for ws in websockets)
-            time = datetime.now().strftime("%H:%M:%S")
             await gather(*tasks)
-            print(f"⏰ - {time}")
 
     routes.static(prefix="/", path=root)
 
